package org.foxarmy.barcodescannerforemployees

import org.foxarmy.barcodescannerforemployees.dataclasses.AbstractProduct

class Parser constructor() {

    fun findNetWeightInText(text: String, regexes: List<Regex>): Pair<String, Double> {
        var text = text
        var netWeight = 0.0
        for (regex in regexes.iterator()) {
            val foundByRegex = regex.find(text)
            if (foundByRegex != null) {
                val found = foundByRegex.groupValues[0]
                text = text.replace(found, "")
                netWeight = stripNetWeight(found)
                when (found.lowercase().strip()) {
                    "кг" -> netWeight *= 1000
                    "мл" -> netWeight /= 1000
                }
                return Pair(text, netWeight)
            }
        }
        return Pair("", 0.0)
    }

    fun parse(text: String): AbstractProduct {
        val (name, netWeight) = findNetWeightInText(
            text,
            listOf(
                Regex("[0-9]+,?[0-9]*  \\s*[лЛ]"),
                Regex("[0-9]+,?[0-9]*\\s*((мл)|(МЛ)|(Мл))"),
                Regex("[0-9]+,?[0-9]*\\s*((кг)|(Кг))"),
                Regex("[0-9]+,?[0-9]*\\s*[гГ]"),
                Regex("[0-9]+,?[0-9*]\\s*((шт)|(Шт))")
            )
        )

        return AbstractProduct(0, "", name, netWeight, "", 0)
    }
}