package org.foxarmy.barcodescannerforemployees.fragments

import android.os.Bundle
import android.provider.BaseColumns
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.gridlayout.widget.GridLayout
import org.foxarmy.barcodescannerforemployees.DBStorageController
import org.foxarmy.barcodescannerforemployees.ProductContract
import org.foxarmy.barcodescannerforemployees.R
import org.foxarmy.barcodescannerforemployees.dataclasses.Product
import org.foxarmy.barcodescannerforemployees.views.ProductView
import kotlin.concurrent.thread

class ShelfFragment : Fragment() {
    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {

        return inflater.inflate(R.layout.fragment_shelf, container, false)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        updateContent()
    }

    override fun onResume() {
        super.onResume()

        updateContent()
    }

    fun updateContent() {
        thread {
            val grv = view?.findViewById<GridLayout>(R.id.contentGridLayout)
            activity!!.runOnUiThread {
                grv?.removeAllViews()
            }

            val db = DBStorageController(requireContext()).readableDatabase
            val projection = arrayOf(
                BaseColumns._ID,
                ProductContract.ProductEntry.ABSTRACT_PRODUCT_ID,
                ProductContract.ProductEntry.AMOUNT,
                ProductContract.ProductEntry.DATE_OF_PRODUCTION,
                ProductContract.ProductEntry.EXPIRY_DATE,
            )

            val cursor = db.query(ProductContract.ProductEntry.TABLE_NAME, projection, null, null, null, null, null)

            with(cursor) {
                while (moveToNext()) {
                    val productId = getInt(getColumnIndexOrThrow(BaseColumns._ID))
                    val abstractProductId =
                        getInt(getColumnIndexOrThrow(ProductContract.ProductEntry.ABSTRACT_PRODUCT_ID))
                    val amount = getInt(getColumnIndexOrThrow(ProductContract.ProductEntry.AMOUNT))
                    val dateOfProduction =
                        getString(getColumnIndexOrThrow(ProductContract.ProductEntry.DATE_OF_PRODUCTION))
                    val dateOfExpiry = getString(getColumnIndexOrThrow(ProductContract.ProductEntry.EXPIRY_DATE))

                    val product = Product(productId, abstractProductId, amount, dateOfProduction, dateOfExpiry)

                    val productView = ProductView(
                        requireActivity(),
                        requireContext(),
                        product
                    )
                    activity!!.runOnUiThread {
                        grv?.addView(productView)
                    }
                }
            }
        }
    }
}